Tampilkan postingan dengan label Hacker. Tampilkan semua postingan
Tampilkan postingan dengan label Hacker. Tampilkan semua postingan

Jumat, 06 Juni 2014

Tutorial Exiftool

Saat kita masuk ke penjelasan exiftool yang panjang bgt kayak baca skripsi
tekan q untuk keluar dari halaman ini
Fitur-fiturnya:
Powerful, fast, flexible and customizable
Supports a large number of different file formats
Reads EXIF, GPS, IPTC, XMP, JFIF, MakerNotes, GeoTIFF, ICC Profile, Photoshop IRB, FlashPix, AFCP, ID3 and more...
Writes EXIF, GPS, IPTC, XMP, JFIF, MakerNotes, ICC Profile, Photoshop IRB, AFCP and more...
Reads and writes maker notes of many digital cameras
Decodes a riddle wrapped in a mystery inside an enigma
Numerous output formatting options (including tab-delimited, HTML, XML and JSON)
Multi-lingual output (cs, de, en, en-ca, en-gb, es, fi, fr, it, ja, ko, nl, pl, ru, sv, tr, zh-cn or zh-tw)
Geotags images from GPS track log files (with time drift correction!)
Generates track logs from geotagged images
Shifts date/time values to fix timestamps in images
Renames files and organizes in directories (by date or by any other meta information)
Extracts thumbnail images, preview images, and large JPEG images from RAW files
Copies meta information between files (even different-format files)
Reads/writes structured XMP information
Deletes meta information individually, in groups, or altogether
Sets the file modification date (and creation date in Windows) from EXIF information
Supports alternate language tags in XMP, PNG, ID3, Font, QuickTime, ICC Profile, MIE and MXF information
Processes entire directory trees
Creates text output file for each image file
Creates binary-format metadata-only (MIE) files for metadata backup
Automatically backs up original image when writing
Organizes output into groups
Conditionally processes files based on value of any meta information
Ability to add custom user-defined tags
Support for MWG (Metadata Working Group) recommendations
Recognizes thousands of different tags
Tested with images from thousands of different camera models
Advanced verbose and HTML-based hex dump outputs.
Ok!!! Lets go!!!!!!!! 
Buat Direktori = mkdir /root/Desktop/Igor
Mounting file2 dari pendrive (/dev/sdc1) saya dan saya akan pindahkan ke direktori /root/Desktop/Igor
Jalankan toolsnya =exiftool /root/Desktop/Igor/alumni.png
saya akan melihat meta data dari foto alumni.png
disini saya akan edit metadata dari foto tadi saya akan tambahkan copyright = true
exiftool -Copyright=True /root/Desktop/Igor/alumni.png
kita cek lagi
exiftool /root/Desktop/Igor/alumni.png
Foto akan menjadi dua bagian yang original dan editan
Saya menambahkan comment didalam meta tag.

Tutorial Exploid DB

Backtrack-Exploitation tools-Opensource Exploitation-Exploit-DB-Exploitdb Search



well hari ini masih kita membahas exploit,,so sebelum memulai tindakan hacking/masuk ke system orang maka diwajibkan mengetahui kerentanan/vulnerability pada system target .... well now i have good idea for this dude without googling and we can find the exploit. tanpa kita sadari sebagi user backtrack ternyata telah terinclude ribuan exploit didalamnnya... ok kali ini kita akan mencari expoit yang ada di backtrak kalian n saya sendiri....
 cd /pentest/exploits/exploitdb
 ls
 OK disini misalnya saya mau mencari exploit yang ada di Os linux menggunakan java
./searchsploit linux java

Exploit Windows 8 Mengunakan Backdoor Msfvenom

Karna hari ini saya masigalau dengan seseorang disana,, hatinya sudah saya exploit dengan kata-kata cinta sebagai backdoornya...tapi sayangnya dia belum membuka sesi meterpreternya.... well kali ini saya akan mengexploit windows 8 lagi :D  Setelah tadi saya membuat cara Exploit Windows 8 Menggunakan Java Signed Applet kali ini kita akan menggunan msfvenom untuk membuat backdoor....dan dihandle sessionya menggunakan msfconsole
msfvenom help = msfvenom -h 
  Cek dan ricek ternyata port defaultnya yg digunkan port 4444
dan saya membuat backdoor menggunakan encoder shikata ga nai,bad charcter,iterations (jumlah encode payload) dan menggunakan port 445.
Senjata saya sudah terpaketkan yang sewaktu-waktu akan meledak dihatimu
(Hasil Perintah diatas adalah
  Dini saya menggunakan handler reverse tcp untuk memastikan korban telah mengesekusi backdoor saya dengan port 445 sebagai gembok rumahnya :d
 dan ternyata dia sudah menerima saya sebagai pacarnya :D i love u shanty
 shanty hatimu baru sebaru windows 8 :D

Tutorial Safecopy

Safecopy tools ini di develop oleh Mbah Corvus Corax berfungsi untuk mengrecover data dari drive bad sector tools ini free (GNU-General Public License) safecopy bisa digunakan pada hardisk,pendrive aka flasdisk,dan CD/VCD.

Safecopy 1.6 by CorvusCorax
Usage: safecopy [options]
Options:
--stage1 : Preset to rescue most of the data fast,
          using no retries and avoiding bad areas.
          Presets: -f 10% -r 10% -R 1 -Z 0 -L 2 -M BaDbLoCk
                   -o stage1.badblocks
--stage2 : Preset to rescue more data, using no retries
          but searching for exact ends of bad areas.
          Presets: -f 128* -r 1* -R 1 -Z 0 -L 2
                   -I stage1.badblocks
                   -o stage2.badblocks
--stage3 : Preset to rescue everything that can be rescued
          using maximum retries, head realignment tricks
          and low level access.
          Presets: -f 1* -r 1* -R 4 -Z 1 -L 2
                   -I stage2.badblocks
                   -o stage3.badblocks
All stage presets can be overridden by individual options.
-b : Blocksize for default read operations.
           Set this to the physical sectorsize of your media.
           Default: 1*
           Hardware block size if reported by OS, otherwise 4096
-f : Blocksize when skipping over badblocks.
           Higher settings put less strain on your hardware,
           but you might miss good areas in between two bad ones.
           Default: 16*
-r : Resolution in bytes when searching for the exact
           beginning or end of a bad area.
           If you read data directly from a device there is no
           need to set this lower than the hardware blocksize.
           On mounted filesystems however, read blocks
           and physical blocks could be misaligned.
           Smaller values lead to very thorough attempts to read
           data at the edge of damaged areas,
           but increase the strain on the damaged media.
           Default: 1*
-R : At least that many read attempts are made on the first
             bad block of a damaged area with minimum resolution.
             More retries can sometimes recover a weak sector,
             but at the cost of additional strain.
             Default: 3
-Z : On each error, force seek the read head from start to
             end of the source device as often as specified.
             That takes time, creates additional strain and might
             not be supported by all devices or drivers.
             Default: 1
-L : Use low level device calls as specified:
                  0  Do not use low level device calls
                  1  Attempt low level device calls
                     for error recovery only
                  2  Always use low level device calls
                     if available
           Supported low level features in this version are:
               SYSTEM  DEVICE TYPE   FEATURE
               Linux   cdrom/dvd     bus/device reset
               Linux   cdrom         read sector in raw mode
               Linux   floppy        controller reset, twaddle
           Default: 1
--sync : Use synchronized read calls (disable driver buffering).
        Safecopy will use O_DIRECT if supported by the OS
        and O_SYNC otherwise.
        Default: Asynchronous read buffering by the OS is allowed
-s : Start position where to start reading.
             Will correspond to position 0 in the destination file.
             Default: block 0
-l : Maximum length of data to be read.
             Default: Entire size of input file
-I : Incremental mode. Assume the target file already
                   exists and has holes specified in the badblockfile.
                   It will be attempted to retrieve more data from
                   the listed blocks or from beyond the file size
                   of the target file only.
                   Warning: Without this option, the destination file
                   will be emptied prior to writing.
                   Use -I /dev/null if you want to continue a previous
                   run of safecopy without a badblock list.
                   Default: none
-i : Blocksize to interpret the badblockfile given with -I.
            Default: Blocksize as specified by -b
-X : Exclusion mode. If used together with -I,
                   excluded blocks override included blocks.
                   Safecopy will not read or write any data from
                   areas covered by exclude blocks.
                   Default: none
-x : Blocksize to interpret the badblockfile given with -X.
            Default: Blocksize as specified by -b
-o : Write a badblocks/e2fsck compatible bad block file.
                   Default: none
-S : Use external script for seeking in input file.
                 (Might be useful for tape devices and similar).
                 Seekscript must be an executable that takes the
                 number of blocks to be skipped as argv1 (1-64)
                 the blocksize in bytes as argv2
                 and the current position (in bytes) as argv3.
                 Return value needs to be the number of blocks
                 successfully skipped, or 0 to indicate seek failure.
                 The external seekscript will only be used
                 if lseek() fails and we need to skip over data.
                 Default: none
-M : Mark unrecovered data with this string instead of
             skipping it. This helps in later finding corrupted
             files on rescued file system images.
             The default is to zero unreadable data on creation
             of output files, and leaving the data as it is
             on any later run.
             Warning: When used in combination with
             incremental mode (-I) this may overwrite data
             in any block that occurs in the -I file.
             Blocks not in the -I file, or covered by the file
             specified with -X are save from being overwritten.
             Default: none
--debug : Enable debug output. Level is a bit field,
                 add values together for more information:
                    program flow:     1
                    IO control:       2
                    badblock marking: 4
                    seeking:          8
                    incremental mode: 16
                    exclude mode:     32
                 or for all debug output: 255
                 Default: 0
-T : Write sector read timing information into
                 this file for later analysis.
                 Default: none
-h | --help : Show this text

Valid parameters for -f -r -b options are:
Amount in bytes - i.e. 1024
% Percentage of whole file/device size - e.g. 10%
* -b only, number times blocksize reported by OS
* -f and -r only, number times the value of -b

Description of output:
. : Between 1 and 1024 blocks successfully read.
_ : Read of block was incomplete. (possibly end of file)
   The blocksize is now reduced to read the rest.
|/| : Seek failed, source can only be read sequentially.
> : Read failed, reducing blocksize to read partial data.
! : A low level error on read attempt of smallest allowed size
   leads to a retry attempt.
[xx](+yy){ : Current block and number of bytes continuously
            read successfully up to this point.
X : Read failed on a block with minimum blocksize and is skipped.
   Unrecoverable error, destination file is padded with zeros.
   Data is now skipped until end of the unreadable area is reached.
< : Successful read after the end of a bad area causes
   backtracking with smaller blocksizes to search for the first
   readable data.
}[xx](+yy) : current block and number of bytes of recent
            continuous unreadable data.
Copyright 2009 CorvusCorax
This is free software. You may redistribute copies of it under
the terms of the GNU General Public License version 2 or above. .
There is NO WARRANTY, to the extent permitted by law.
OK Without bacot lebih baik kita mulai deh:
disini saya menggunakan 2 pendrive/flasdisk
flasdisk yang badsector terletak di  /dev/sdb1 dan isi/data dari pendrive yang badsector saya  akan pindahkan ke  /dev/sdc1 yang masih gress baru beli tadi hehheee.........
Kita Hidupkan mesin safecopynya \
safecopy /dev/sdb1 /media/KINGSTON/dataku
/dev/sdb1 merupakan letak pendrive badsector
media merupakan Alur yang akan menjembatani /dev/sdb1 dan /dev/sdc1
KINGSTON = nama pendrive/flasdisk saya (/dev/sdc1)
dataku = tempat penyimpanan recovery data 
atau bisa juga simpan di Desktop
safecopy /dev/sdb1 /root/Desktop/dataku
Pengecekan dan proses pemindahan seluruh sector dalam flasdisk saya
ternyata flasdisk gue gak bad sector next time or kalau ada hardisk or anything bad sector cobain sendiri deh bro oke...
Data sudah terrecovery di pendrive kingston saya sebesar 3,8 GB..

Tutorial WebSecurify



Websecurify Merupakan tools pentesting web yang sudah terinstall di Backtrack 5 R3...Tool ini mampu mengumpulkan informasi tentang web target seperti potensi serangan xss,injection, email gathering,info patch system. Websecurify juga didukung oleh banyak Operating System (linux,unix,windows,Iphone,Mac OS,Android.
Letaknya di Backtrack-->Eksploitation Tools-->Web Exploitation Tools-->Websecurify
Klik bagian HOME pojok kiri atas
Setelah Memasukkan nama web tekan enter dan ada warning centang Continue
Biarkan Scanning berjalan sampai 100 %, jika sudah selesai KLik tanda paling bawah 
Hasil scanning CrossRequest Forgery berserta solusi pathnya
Path disclosure berisi penjelasan cara attacker memanfaatkan celah dan cara mengatasinya
IP disclosure hampir sama penjelasan diatas berisi penjelasan dan solusi 
Eror Disclosure mendeteksi eror didaam system web dan solusinya
Email Disclosure Menampilkan email  web....
Banner Disclosure menampilkan Server yang digunakan
Sekain Dan Terima Kasih

Tutorial DotDotPwn

dotdotpwn -- Direktory Tranversal Tool
cd /pentest/web/dotdotpwn
visit web : DOTDOTPWN
merupakan tools pendeteksi bebrapa Direktori Tranversal Vulnerability di HTTP/FTP server. AttackDB version saat ini telah memiliki 871 tranversal payload.. tool ini telah dicoba di kolibri+webserver v2.0 dan GeFest WebServer v.1.0 (http server)..dan hasilnya bebrapa string2 vulnerability di dapatkan.
dotdotpwn mampu mendeteksi 10 - 20 perbedaaan serangan strings di server yang vulnerability..
fitur-fitur dotdotpwn:
1.Mendeteksi Direktory transversal vulnerability di HTTP/FTP sistem server.
2.dotdotpwn mengecek di boot.ini di system yang vulnerability melalaui direktory transversal .jadi asumsinya mengetes di web server dengan base sistem windows.
3.Transversal databasenya sekitar 871 payload. -update flag untuk fresh update

Usage: ./dotdotpwn.pl -m -h [OPTIONS]
Available options:
-m Module [http | http-url | ftp | tftp | payload | stdout]
-h Hostname
-O Operating System detection for intelligent fuzzing (nmap)
-o Operating System type if known ("windows", "unix" or "generic")
-s Service version detection (banner grabber)
-d Deep of traversals (e.g. deepness 3 equals to ../../../; default: 6)
-f Specific filename (e.g. /etc/motd; default: according to OS detected, defaults in TraversalEngine.pm)
-E Add @Extra_files in TraversalEngine.pm (e.g. web.config, httpd.conf, etc.)
-u URL with the part to be fuzzed marked as TRAVERSAL (e.g. http://foo:8080/id.php?x=TRAVERSAL&y=31337)
-k Text pattern to match in the response (http-url & payload modules - e.g. "root:" if trying /etc/passwd)
-p Filename with the payload to be sent and the part to be fuzzed marked with the TRAVERSAL keyword
-x Port to connect (default: HTTP=80; FTP=21; TFTP=69)
-t Time in milliseconds between each test (default: 300 (.3 second))
-X Use the Bisection Algorithm to detect the exact deepness once a vulnerability has been found
-e File extension appended at the end of each fuzz string (e.g. ".php", ".jpg", ".inc")
-U Username (default: 'anonymous')
-P Password (default: 'dot@dot.pwn')
-M HTTP Method to use when using the 'http' module [GET | POST | HEAD | COPY | MOVE] (default: GET)
-r Report filename (default: 'HOST_MM-DD-YYYY_HOUR-MIN.txt')
-b Break after the first vulnerability is found
-q Quiet mode (doesn't print each attemp)
--m Module [http | http-url | ftp | tftp | payload | stdout]
-h Hostname
Hasil yang saya save di dir /pentest/web/dotdotpwn
nautilus /pentest/web/dotdotpwn

Tutorial FatBack


FatBack-Forensic Tools
Dideveloped oleh Departement Pertahanan pada tahun 2000-2001 Computer Forensic Lab.
Oleh SrA Nicholas Harbour
Fatback digunakan untuk mengrecover file yang terhapus di FAT
(File Allocation Table) File System.
Fatback juga bisa digunakan di gunakan di Sytem Windows.
 OK saya menggunakan backtrack 5 R3 
Letak Fatback di : Backtrack-->Forensic-->Forensic Carving Tools-->Fatback
a.fatback digunakan untuk memulai program
b.-a auto mode
c./dev/sdc1 = nama/letak partisi pendrive/flasdisk
d.-o =spesifik direktory tempat output file (root/OutputPendrive) jadi hasilnya ada direktory root;


Disini saya menggunaakan Flasdisk
ketik ls -l
lihat lokasi/tempat flasdisk kita dipojok kiri bawah.
/dev/sdc1

OK ini isi data saya sebelum saya Shift+del (delete permanen).

Setelah saya hapus saya sisakan satu....sebagai bukti wkakkaaaa...(boleh dihapus semua kok :p)


OK lets go kita kembalikan data2 yang hilang dimakan bajol tadi hahhaaaaa
fatback -a /dev/sdc1 -o /root/OutputPendrive
Ok setelah itu kita buka Di dir Root/Home (cari OutputPendrive).
Setelah dibuka ada semua tu file back yang tadi kita Shift+del
Saya Buka satu filenya OH masih baik2 saja.

Tutorial Golismero

Ringkasan ini tidak tersedia. Harap klik di sini untuk melihat postingan.

Postingan Lama Beranda